@@ -503,17 +503,23 @@ class Matcher(Preprocessor):
                                'Gene Priority'])
     
     if self.one_match:
-      try:
+      if df['Protein Evidence Level'].isnull().values.any():
+        df.drop_duplicates(['Peptide Sequence'], inplace=True)
+        return df
+
+      else:
         idx = df.groupby(['Peptide Sequence'])['Protein Evidence Level'].transform('min') == df['Protein Evidence Level']
         df = df[idx]
 
+      if df['Gene Priority'].isnull().values.any():
+        df.drop_duplicates(['Peptide Sequence'], inplace=True)
+        return df
+
+      else:
         idx = df.groupby(['Peptide Sequence'])['Gene Priority'].transform('max') == df['Gene Priority']
         df = df[idx]
-
-        df.drop_duplicates(['Peptide Sequence'], inplace=True)
-
-      except KeyError:
-        df.drop_duplicates(['Peptide Sequence'], inplace=True)
+      
+      df.drop_duplicates(['Peptide Sequence'], inplace=True)
 
     return df 
 
